# Simple UNSC Sanctions checker with a GUI and fuzzy matching.

Simple GUI for checking names against the UNSC Sanctions List.

Uses fuzzy matching score for hits.

Loads sanctions list in xml format. You can supply your own list or download it
from the UNSC website from within the program.



